Page 5 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 5

Home

    Beginning in the early 1960s, an increasing number of
    books and articles exposing the existence of a powerful
    world wide movement dedicated to _creating a New

    World Order began to appear. Although the news media
    ignored these books and articles, as time passed, the
    media's own headlines bore out the worth of their

    allegations.
    As the evidence accumulated, an amazing parallel to

    a world structure pictured in the seventeenth and
    eighteenth chapter of the Book of Revelation became
    apparent. This book is the result of viewing that

    apparent. This book is the result of viewing that
    unfolding parallel for nearly thirty years.

    Since our subject deals in part with Bible prophecy,
    we wish to state at the very beginning that no Scriptural
    prophecy directs believers to acquiesce to evil. The
    admonition given in Romans 12:21 to, "Be not overcome

    of evil, but overcome evil with good" applies to all
    situations whenever and wherever evil appears.

    Since the beginning of recorded history mankind has
    been involved in a continuous struggle between good and
    evil, between the spiritual forces of light and the spiritual
    forces of darkness. No place in Scripture is there an
    admonition for believers to be passive bystanders.

    Throughout history those working for good have
    worked openly and often alone. Those working for evil

    ix

    Introduction